.. _auth_module:

:mod:`cubicweb.pyramid.auth`
----------------------------

.. automodule:: cubicweb.pyramid.auth

    .. autofunction:: includeme

    .. autoclass:: UpdateLoginTimeAuthenticationPolicy
        :show-inheritance:
        :members:
